gg_localize_refs library

Classes

BackupPublishTo
Command that backs up the original publish_to value of a Dart project.
ChangeRefsToGitFeatureBranch
Command that changes workspace dependencies to git references.
ChangeRefsToLocal
Command for localizing references to local path dependencies.
ChangeRefsToPubDev
Command that reverts localized references back to remote dependencies.
DartRefsRestore
The outcome of restoring the localized Dart refs of one project.
GetRefVersion
Command that reads the current version/spec of a dependency from pubspec.yaml or package.json.
GetVersion
Command that reads the current package version from pubspec.yaml or package.json.
GgToLocal
The command line interface for GgToLocal.
PnpmWorkspaceIo
Reads and edits the overrides section of a pnpm-workspace.yaml.
PubspecOverridesEdit
The outcome of computing an edit for an overrides file — pubspec_overrides.yaml (Dart) or pnpm-workspace.yaml (TypeScript).
PubspecOverridesIo
Reads and edits the dependency_overrides of a pubspec_overrides.yaml.
RestorePublishTo
Command that restores the original publish_to value from the backup.
SetRefVersion
Command that sets the version/spec of a dependency in pubspec.yaml or package.json. Operates directly on the manifest in the input directory; does not traverse a workspace.
TypeScriptRefsRestore
The outcome of restoring the localized TypeScript refs of one project.